@@ -4,33 +4,19 @@
 #' specify autopilot modes using the list values, e.g. AutopilotMode$FullAuto instead of typing
 #' the string 'auto'. This way you can benefit from autocomplete and not have to remember the valid
 #' optons.
-#'
 #' @export
-#'
 AutopilotMode <- list(
   FullAuto = 'auto',
-  SemiAuto = 'semi',
   Manual = 'manual',
   Quick = 'quick')
 
-
-PredictJobStatus <- list(
-  Queue = 'queue',
-  InProgress = 'inprogress',
-  Error = 'error',
-  Aborted = 'ABORTED')
-
-
 #' Job statuses
 #'
 #' This is a list that contains the valid values for job status when querying the list of jobs mode.
 #' If you wish, you can specify job status modes using the list values, e.g. JobStatus$InProgress
-#' instead of typing the string 'inprogress'. This way you can benefit from autocomplete and not have to
-#' remember the valid optons.
-#'
-#'
+#' instead of typing the string 'inprogress'. This way you can benefit from autocomplete and not
+#' have to remember the valid optons.
 #' @export
-#'
 JobStatus <- list(
   Queue = 'queue',
   InProgress = 'inprogress',
@@ -43,9 +29,7 @@ JobFailureStatuses <- c(JobStatus$Error, JobStatus$Aborted)
 #' Job type
 #'
 #' This is a list that contains the valid values for job type when querying the list of jobs.
-#'
 #' @export
-#'
 JobType <- list(
   FeatureImpact = 'featureImpact',
   Predict = 'predict',
@@ -61,9 +45,7 @@ JobType <- list(
 #' Prime Language
 #'
 #' This is a list that contains the valid values for downloadable code programming languages.
-#'
 #' @export
-#'
 PrimeLanguage <- list(
   Python = 'Python',
   Java = 'Java')
@@ -71,9 +53,7 @@ PrimeLanguage <- list(
 #' PostgreSQL drivers
 #'
 #' This is a list that contains the valid values for PostgreSQL drivers.
-#'
 #' @export
-#'
 PostgreSQLdrivers <- list(
   Unicode = 'PostgreSQL Unicode',
   ANSI = 'PostgreSQL ANSI')
@@ -81,27 +61,35 @@ PostgreSQLdrivers <- list(
 #' Blend methods
 #'
 #' This is a list that contains the valid values for Blend methods
-#'
 #' @export
-#'
 BlendMethods <- list(
   PLS = 'PLS',
   GLM = 'GLM',
   ENET = 'ENET',
   MED = 'MED',
-  AVERAGE = 'AVG'
-  )
+  AVERAGE = 'AVG',
+  MAE = 'MAE',
+  MAEL1 = 'MAEL1'
+ )
 
 #' CV methods
 #'
 #' This is a list that contains the valid values for CV methods
-#'
 #' @export
-#'
 cvMethods <- list(
   RANDOM = 'random',
   STRATIFIED = 'stratified',
   USER = 'user',
   GROUP = 'group',
   DATETIME = 'datetime'
-  )
+ )
+
+#' Data Partition methods
+#'
+#' This is a list that contains the valid values for data partitions
+#' @export
+DataPartition <- list(
+  VALIDATION = 'validation',
+  CROSSVALIDATION = 'crossValidation',
+  HOLDOUT = 'holdout'
+ )
